==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/ItemToolTipLayerDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { AnnotationLayerDescription } from "./AnnotationLayerDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var ItemToolTipLayerDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ItemToolTipLayerDescription, _super);
    function ItemToolTipLayerDescription() {
        var _this = _super.call(this) || this;
        _this.di = null;
        _this.dj = null;
        _this.df = false;
        _this.de = false;
        return _this;
    }
    ItemToolTipLayerDescription.prototype.get_type = function () {
        return "ItemToolTipLayer";
    };
    Object.defineProperty(ItemToolTipLayerDescription.prototype, "targetSeriesName", {
        get: function () {
            return this.di;
        },
        set: function (a) {
            this.di = a;
            this.e("TargetSeriesName");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ItemToolTipLayerDescription.prototype, "targetSeriesRef", {
        get: function () {
            return this.dj;
        },
        set: function (a) {
            this.dj = a;
            this.e("TargetSeriesRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ItemToolTipLayerDescription.prototype, "useInterpolation", {
        get: function () {
            return this.df;
        },
        set: function (a) {
            this.df = a;
            this.e("UseInterpolation");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ItemToolTipLayerDescription.prototype, "skipUnknownValues", {
        get: function () {
            return this.de;
        },
        set: function (a) {
            this.de = a;
            this.e("SkipUnknownValues");
        },
        enumerable: true,
        configurable: true
    });
    ItemToolTipLayerDescription.$t = markType(ItemToolTipLayerDescription, 'ItemToolTipLayerDescription', AnnotationLayerDescription.$);
    return ItemToolTipLayerDescription;
}(AnnotationLayerDescription));
export { ItemToolTipLayerDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/ItemToolTipLayerDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnnotationLayerDescription } from "./AnnotationLayerDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var ItemToolTipLayerDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ItemToolTipLayerDescription, _super);
    function ItemToolTipLayerDescription() {
        var _this = _super.call(this) || this;
        _this.gh = null;
        _this.gi = null;
        _this.ge = false;
        _this.gd = false;
        return _this;
    }
    ItemToolTipLayerDescription.prototype.get_type = function () {
        return "ItemToolTipLayer";
    };
    Object.defineProperty(ItemToolTipLayerDescription.prototype, "targetSeriesName", {
        get: function () {
            return this.gh;
        },
        set: function (a) {
            this.gh = a;
            this.g("TargetSeriesName");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ItemToolTipLayerDescription.prototype, "targetSeriesRef", {
        get: function () {
            return this.gi;
        },
        set: function (a) {
            this.gi = a;
            this.g("TargetSeriesRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ItemToolTipLayerDescription.prototype, "useInterpolation", {
        get: function () {
            return this.ge;
        },
        set: function (a) {
            this.ge = a;
            this.g("UseInterpolation");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ItemToolTipLayerDescription.prototype, "skipUnknownValues", {
        get: function () {
            return this.gd;
        },
        set: function (a) {
            this.gd = a;
            this.g("SkipUnknownValues");
        },
        enumerable: false,
        configurable: true
    });
    ItemToolTipLayerDescription.$t = markType(ItemToolTipLayerDescription, 'ItemToolTipLayerDescription', AnnotationLayerDescription.$);
    return ItemToolTipLayerDescription;
}(AnnotationLayerDescription));
export { ItemToolTipLayerDescription };
